@@ -191,7 +191,7 @@ class CustomFalconReader:
         self.start = 0
         dataset = []
         if not endpoint_name:
-            raise Exception(
+            raise KeyError(
                 "Please specify endpoint in the configs i.e content_metrics or published_posts"
             )
         if endpoint_name == "content_metrics":
@@ -212,7 +212,7 @@ class CustomFalconReader:
                 dataset.extend(results)
                 self.start += 1
         else:
-            raise Exception(f"Invalid endpoint_name {endpoint_name}")
+            raise ValueError(f"Invalid endpoint_name {endpoint_name}")
 
         return dataset
 
@@ -237,7 +237,7 @@ class CustomFalconReader:
             if len(payload) > 0:
                 yield {
                     "networks": self._config["networks"],
-                    "date": date.replace("-", ""),
+                    "date": date,
                     "data": payload,
                 }
             else:
