@@ -49,7 +49,7 @@ class CustomGBQReader:
         else:
             metrics = ''.join(metric)
             if metrics == 'session_start':
-                query_suffix =  f" and event_name = '{metrics}'"
+                query_suffix =  f" = '{metrics}'"
                 query = query_prefix + table_name + parameters + query_suffix
             elif metrics == 'leads':
                 query_prefix = "SELECT * FROM (SELECT *, (SELECT value.string_value"
