@@ -21,6 +21,7 @@ class CustomS3JsonWriter:
             self.boto3_session = boto3.Session()
         else:
             self.boto3_session = boto3.Session(profile_name=profile_name)
+        self.s3_resource = self.boto3_session.resource("s3")
 
     def write_partition_to_s3(self, json_data):
         """
@@ -32,8 +33,8 @@ class CustomS3JsonWriter:
         dimension = json_data["dimension"]
         date = json_data["date"].replace('-', '')
         dataset = json_data["data"]
-        metric = json_data["metric"]
-        key_path = f"{self.file_path}/{metric}/{dimension}/{date}.json"
+        #metric = json_data["metric"]
+        key_path = f"{self.file_path}/{dimension}/{date}.json"
         print(f"Writing data to {key_path}.")
         self.s3_resource.Object(self.bucket, key_path).put(
             Body=json.dumps(dataset)
