@@ -5,14 +5,14 @@ import yaml
 
 def get_config(configs, fmt):
     """
-        Gathers query configurations from json or yaml.
+    Gathers query configurations from json or yaml.
     """
     if configs is not None:
-        if fmt in ['yaml', 'yml']:
-            with open(configs, 'r') as file:
+        if fmt in ["yaml", "yml"]:
+            with open(configs, "r") as file:
                 config = yaml.safe_load(file)
-        elif fmt == 'json':
-            with open(configs, 'r') as file:
+        elif fmt == "json":
+            with open(configs, "r") as file:
                 config = json.load(file)
 
     return config
