@@ -1,4 +1,7 @@
-# pylint: disable=no-self-use
+# pylint: disable=no-self-use,unused-import,too-few-public-methods,raise-missing-from,broad-except,too-many-instance-attributes
+""""
+MODULE FOR ONESIGNAL API CALL
+"""
 import json
 import time
 from datetime import datetime
@@ -14,6 +17,8 @@ from sdc_dp_helpers.api_utilities.retry_managers import retry_handler, request_h
 
 
 class CustomOneSignalReader:
+    """ "One Signal Custom Reader class"""
+
     def __init__(self, creds_file, config_file, **kwargs):
         self._creds = load_file(creds_file, "yml")
         self._config = load_file(config_file, "yml")
@@ -57,6 +62,7 @@ class CustomOneSignalReader:
             url=url,
             headers=self._header,
             params={"limit": limit, "total_count": "true", "offset": offset},
+            timeout=30
         )
 
     @request_handler(wait=1, backoff_factor=0.5)
@@ -65,7 +71,7 @@ class CustomOneSignalReader:
         Handles the csv export request attempt.
         """
         url = self._generate_url(endpoint="csv_export")
-        return requests.post(url=url, headers=self._header)
+        return requests.post(url=url, headers=self._header, timeout=30)
 
     def _get_csv_export_handler(self, response):
         """
@@ -120,7 +126,7 @@ class CustomOneSignalReader:
     def run_query(self):
         """
         Generate a compressed CSV export of all of your current user data.
-        This method can be used to generate a compressed CSV export of all of your current user data.
+        This method can be used to generate a compressed CSV export of current user data.
         View the details of multiple notifications.
         :return: The response dataset.
         """
