@@ -1,15 +1,18 @@
-import requests, json
-
+# pylint: disable=missing-function-docstring,missing-module-docstring,missing-class-docstring,unused-import,import-error,ungrouped-imports,wildcard-import,unused-argument,unused-wildcard-import
+import json
+import ast
+import requests
+from oauth2 import *
 from xero.auth import OAuth2Credentials
 from xero.exceptions import XeroForbidden
-from oauth2 import *
-import ast
+
 
 def token_isvalid(creds: OAuth2Credentials) -> bool:
     if not isinstance(creds, OAuth2Credentials):
         raise TypeError("creds is not an object of type OAuth2Credentials")
-    
-    return (creds.get_tenants()[0]['tenantId'] is not None)
+
+    return creds.get_tenants()[0]["tenantId"] is not None
+
 
 def get_auth_token(client_id: str, local_token_path: str) -> OAuth2Credentials:
     """
@@ -24,21 +27,23 @@ def get_auth_token(client_id: str, local_token_path: str) -> OAuth2Credentials:
     if (not client_id) or (len(client_id) != 32):
         raise ValueError("Invalid client_id")
 
-    with open( local_token_path, "r" ) as token_file:
-        auth_token = ast.literal_eval( token_file.read() )
-    print("original token:", auth_token )
-    auth_creds = OAuth2Credentials( client_id, client_secret="", token=auth_token )
+    with open(local_token_path, "r") as token_file:
+        auth_token = ast.literal_eval(token_file.read())
+    print("original token:", auth_token)
+    auth_creds = OAuth2Credentials(client_id, client_secret="", token=auth_token)
     return refresh_auth_token(client_id, auth_creds, local_token_path)
 
 
-def refresh_auth_token(client_id: str, auth_creds: OAuth2Credentials, local_token_path: str) -> OAuth2Credentials:
+def refresh_auth_token(
+    client_id: str, auth_creds: OAuth2Credentials, local_token_path: str
+) -> OAuth2Credentials:
     cred = {
         "grant_type": "refresh_token",
         "refresh_token": auth_creds.token["refresh_token"],  #
         "client_id": client_id,
     }
-    #print(cred, auth_creds.token)
-    response = requests.post("https://identity.xero.com/connect/token", cred)
+    # print(cred, auth_creds.token)
+    response = requests.post("https://identity.xero.com/connect/token", cred, timeout=30)
     auth_token = response.json()
     print("response:", auth_token)
     print("auth keys", auth_token.keys())
@@ -47,18 +52,21 @@ def refresh_auth_token(client_id: str, auth_creds: OAuth2Credentials, local_toke
         raise Exception(err_message)
 
     print("Writing new Xero token to path: ", local_token_path)
-    with open(local_token_path, 'w') as outfile:
-        outfile.write( json.dumps(auth_token) )
+    with open(local_token_path, "w") as outfile:
+        outfile.write(json.dumps(auth_token))
 
-    auth_creds = OAuth2Credentials( client_id, client_secret="", token=auth_token )
+    auth_creds = OAuth2Credentials(client_id, client_secret="", token=auth_token)
     if not token_isvalid(auth_creds):
-        raise XeroForbidden(f"An error occured while trying to authenticate the refreshed token: {str(auth_creds)}")
+        raise XeroForbidden(
+            f"Error while trying to authenticate the refreshed token: {str(auth_creds)}"
+        )
     return auth_creds
 
+
 def save_auth_token(auth_token):
     """
     function to persist the latest auth token to s3
     """
-    # TODO: pull update_refresh_token from readers into here
-    
+    # TO DO: pull update_refresh_token from readers into here
+
     pass
